@@ -1,6 +1,7 @@
 from logging import StreamHandler
 
 import jwt
+import requests
 from functools import wraps
 from firebase_admin import firestore
 from flask import request, abort, json
@@ -51,7 +52,7 @@ def get_scopes(tenant_id=None):
 
         if tenant_id == decoded_token.get('firebase').get('tenant'):
             if host:
-                roles = get_user_roles()
+                roles = get_user_roles(host)
                 scopes = []
                 for role in roles:
                     if role['name'] in user_roles:
@@ -74,27 +75,15 @@ def get_scopes(tenant_id=None):
     return abort(403, "NOT ALLOWED")
 
 
-def get_user_roles():
-    db = firestore.client()
-    roles = []
-
-    roles_ref = db.collection(u'userRoles')
-    docs = roles_ref.stream()
-
-    for doc in docs:
-        roles.append(doc.to_dict())
+def get_user_roles(host):
+    response = requests.get(host+'/roles/users')
+    roles = json.loads(response.text)
 
     return roles
 
 
 def get_platform_roles():
-    db = firestore.client()
-    roles = []
-
-    roles_ref = db.collection(u'platformRoles')
-    docs = roles_ref.stream()
-
-    for doc in docs:
-        roles.append(doc.to_dict())
+    response = requests.get(host+'/roles/platform')
+    roles = json.loads(response.text)
 
     return roles
